@@ -324,9 +324,10 @@ class LXDDriver(driver.ComputeDriver):
             profile = self.client.profiles.get(instance.name)
             config_drive = {
                 'configdrive': {
-                    'path': '/var/lib/cloud/data',
+                    'path': '/config-drive',
                     'source': configdrive_path,
                     'type': 'disk',
+                    'readonly': True,
                 }
             }
             profile.devices.update(config_drive)
